@@ -159,11 +159,14 @@ int get_logs(unsigned n, logent *cplogs){
 
 void diag(const char *fmt,...){
   va_list vac,ap;
-
-  va_start(ap,fmt);
-  va_copy(vac,ap);
-  gui->vdiag(fmt,ap);
-  add_log(fmt,vac);
+  va_start(ap, fmt);
+  va_copy(vac, ap);
+  if(gui){
+    gui->vdiag(fmt, ap);
+    add_log(fmt, vac);
+  }else{
+    vfprintf(stderr, fmt, ap);
+  }
   va_end(vac);
 }
 
@@ -1027,24 +1030,17 @@ rescan(const char *name,device *d){
       }
       close(dfd);
     }
-    snprintf(devbuf,sizeof(devbuf),DEVROOT "/%s",name);
+    snprintf(devbuf, sizeof(devbuf), DEVROOT "/%s", name);
     // FIXME move all this to its own function
-    if(probe_blkid_superblock(devbuf,&pr,d) == 0){
-      if( (ppl = blkid_probe_get_partitions(pr)) ){
+    if(probe_blkid_superblock(devbuf, &pr, d) == 0){
+      if( (ppl = blkid_probe_get_partitions(pr)) && (ptbl = blkid_partlist_get_table(ppl))){
         const char *pttable;
         device *p;
 
-        if((ptbl = blkid_partlist_get_table(ppl)) == NULL){
-          diag("Couldn't probe partition table of %s (%s)\n",name,strerror(errno));
-          clobber_device(d);
-          blkid_free_probe(pr);
-          return NULL;
-        }
         pars = blkid_partlist_numof_partitions(ppl);
         pttable = blkid_parttable_get_type(ptbl);
         verbf("\t%d partition%s, table type %s\n",
-            pars,pars == 1 ? "" : "s",
-            pttable);
+              pars, pars == 1 ? "" : "s", pttable);
         switch(d->layout){
           case LAYOUT_NONE: d->blkdev.pttable = strdup(pttable); break;
           case LAYOUT_MDADM: d->mddev.pttable = strdup(pttable); break;
@@ -1054,17 +1050,17 @@ rescan(const char *name,device *d){
         for(p = d->parts ; p ; p = p->next){
           blkid_partition part;
 
-          part = blkid_partlist_devno_to_partition(ppl,p->devno);
+          part = blkid_partlist_devno_to_partition(ppl, p->devno);
           if(part){
             unsigned long long flags;
 
-            if(probe_blkid_superblock(p->name,NULL,p)){
+            if(probe_blkid_superblock(p->name, NULL, p)){
               clobber_device(d);
               blkid_free_probe(pr);
               return NULL;
             }
             flags = blkid_partition_get_flags(part);
-            if(strcmp(pttable,"gpt") == 0){
+            if(strcmp(pttable, "gpt") == 0){
               // FIXME verify bootable flag?
             }else{
               if(blkid_partition_is_logical(part)){
@@ -1092,11 +1088,10 @@ rescan(const char *name,device *d){
           }
         }
       }else{
-        device *p;
-
         verbf("\tNo partition table\n");
+        device *p;
         while( (p = d->parts) ){
-          diag("Eliminating malingering partition %s\n",p->name);
+          diag("Eliminating malingering partition %s\n", p->name);
           d->parts = p->next;
           clobber_device(p);
         }
